# -*- coding: utf-8 -*-

from rest_framework import serializers

from thx.api.serializers import (
    ThuxListSerializerMixin, ThuxRetrieveSerializerMixin, ThuxCreateSerializerMixin,
    ThuxUpdateSerializerMixin, ThuxPartialUpdateSerializerMixin, ThuxStatusSerializerMixin,
    ThuxEnableSerializerMixin, ThuxDisableSerializerMixin
)
from thx.role.core.serializers import ThuxRoleSerializerMixin

from ... import models


# LANGUAGE
class LanguageSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_i18n_language'
        model = models.Language
        fields = '__all__'


class LanguageListSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_i18n_language_list'
        model = models.Language
        fields = '__all__'


class LanguageRetrieveSerializer(ThuxRoleSerializerMixin, ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_i18n_language_retrieve'
        model = models.Language
        fields = '__all__'


class LanguageCreateSerializer(ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_i18n_language_create'
        model = models.Language
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def to_representation(self, instance):
        return LanguageListSerializer(instance, context=self.context).data


class LanguageUpdateSerializer(ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_i18n_language_update'
        model = models.Language
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def to_representation(self, instance):
        return LanguageRetrieveSerializer(instance, context=self.context).data


class LanguagePartialUpdateSerializer(
    ThuxRoleSerializerMixin, ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer
):
    class Meta:
        ref_name = 'v1_i18n_language_partial_update'
        model = models.Language
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def to_representation(self, instance):
        return LanguageRetrieveSerializer(instance, context=self.context).data


class LanguageEnableSerializer(ThuxRoleSerializerMixin, ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_i18n_language_enable'
        model = models.Language
        fields = ()

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance

    def to_representation(self, instance):
        return LanguageRetrieveSerializer(instance, context=self.context).data


class LanguageDisableSerializer(ThuxRoleSerializerMixin, ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_i18n_language_disable'
        model = models.Language
        fields = ()

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance

    def to_representation(self, instance):
        return LanguageRetrieveSerializer(instance, context=self.context).data
